# Docker-Compose Library
A collection of docker-compose files for different open-source projects.

**Disclaimer**: most files are to be understood as "getting started" level. Make sure to think about security whenever you expose some service to the Internet! Please check out the projects using the links below for any updates and best practices (most projects have their own guide on how to create a docker-compose file for hosting them).

## About volumes
- You will find that most files reference volumes as paths. This is because I find it easier to backup and handle volumes if they are located either next to the `docker-compose.yml` file or at a specific directory on the host. 
- Please note, that sometimes it can be necessary to change the permissions of these directories to match the user under which the container is executed!

## Prerequisites

- To run these files you must install the `Docker` engine on your host. Detailed information on how to install Docker on your operating system can be found [here](https://docs.docker.com/engine/install/). 
- Additionally `docker-compose` is needed. See how to install it [here](https://docs.docker.com/compose/install/).

If you are using [OpenSUSE](https://en.opensuse.org/Docker), you can use these commands to installl the needed tools.

```bash
# install packages
sudo zypper install docker docker-compose docker-compose-switch

# add docker-daemon to start automatically on boot
sudo systemctl enable docker

# start the docker-daemon
sudo systemctl restart docker

# check that docker-daemon is running
sudo docker run --rm hello-world
```

## List of compose files
The following compose files can be found in this repository.
- bookstack | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://www.bookstackapp.com/)
- dashy | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://dashy.to/)
- gitea | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://about.gitea.com/)
- grafana | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://grafana.com/)
- gramps | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://gramps-project.org)
- jenkins | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://www.jenkins.io/)
- kanboard | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://kanboard.org/)
- keycloak | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://www.keycloak.org/)
- mediawiki | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://www.mediawiki.org)
- nextcloud | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://nextcloud.com/)
- offen | [docker-compose.yml](./bookstack/docker-compose.yml) | [Link to project](https://www.offen.dev/)

## Proxy
- Most docker-compose files are created with having a reverse-proxy infront of them to do SSL termination and subdomain binding. 
- In each directory you will find a `nginx.conf` file for NGINX to use. Please note that this file is not including SSL certificates. 
- To provide SSL automatically I recommend using [certbot](https://certbot.eff.org/)


